@@ -25,11 +25,11 @@ Marketplace::Ebay - Making API calls to eBay (with XSD validation)
 
 =head1 VERSION
 
-Version 0.16
+Version 0.17
 
 =cut
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 =head1 SYNOPSIS
 
@@ -103,11 +103,20 @@ The version of API and XSD used. Please keep this in sync with the XSD.
 You can get the HTTP::Response object of the last call using this
 accessor.
 
+=head2 last_request
+
+You can get the HTTP::Request object of the last call using this
+accessor.
+
 =head3 last_parsed_response
 
 Return a L<Marketplace::Ebay::Response> object (or undef on failure)
 out of the return value of the last C<api_call>.
 
+=head3 log_file
+
+A filename where to log requests and responses.
+
 =cut
 
 has developer_key =>   (is => 'ro', required => 1);
@@ -196,6 +205,10 @@ Utility for development. Show the expected structure for the API call
 $call. The second argument is optional, and may be Request or
 Response, defaulting to Request.
 
+=head2 log_event(@data)
+
+Append the arguments to the C<log_file>, if it was defined.
+
 =cut
 
 sub api_call {
@@ -482,6 +495,11 @@ sub get_orders_for_site {
     return grep { $_->ebay_site eq $name } @orders;
 }
 
+=head2 ebay_site_code_types (internal)
+
+L<http://developer.ebay.com/devzone/XML/docs/Reference/ebay/types/SiteCodeType.html>
+turned into an hashref to map the site name to an id.
+
 =head2 ebay_sites_name_to_id
 
 Return an hashref for mapping ebay site names and abbreviations to a numeric id.
@@ -494,7 +512,7 @@ Return an hashref for mapping ebay site id to its name.
 =cut
 
 sub ebay_site_code_types {
-    # http://developer.ebay.com/devzone/XML/docs/Reference/ebay/types/SiteCodeType.html
+
     my %codes = (
                  Australia  => { id => 15, abbreviation => "AU" },
                  Austria  => { id => 16, abbreviation => "AT" },
